@@ -1,4 +1,4 @@
-#' Get Daylight Savings Time indicator of a date-time.
+#' Get **d**aylight **s**avings **t**ime indicator of a date-time
 #'
 #' Date-time must be a POSIXct, POSIXlt, Date, chron, yearmon, yearqtr, zoo,
 #' zooreg, timeDate, xts, its, ti, jul, timeSeries, and fts objects.
@@ -13,9 +13,11 @@
 #' @examples
 #' x <- ymd("2012-03-26")
 #' dst(x)
-dst <- function(x)
+dst <- function(x) {
   UseMethod("dst")
+}
 
 #' @export
-dst.default <- function(x)
+dst.default <- function(x) {
   c(NA, FALSE, TRUE)[as.POSIXlt(x)$isdst + 2]
+}
