@@ -471,7 +471,7 @@ parse_period <- function(x) {
     stop("Interval or Durations objects cannot be used as input to 'period()' constructor. Plese use 'as.period()'.")
   }
 
-  stop_incompatible_size(num, units)
+  stop_incompatible_sizes(num, units)
   if (length(units) > length(num)) {
     num <- rep_len(num, length(units))
   }
